| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.ChimeSDKIdentity.Types.Tag
Description
Documentation
A tag object containing a key-value pair.
See: newTag smart constructor.
Constructors
| Tag' | |
Instances
| FromJSON Tag Source # | |
| ToJSON Tag Source # | |
Defined in Amazonka.ChimeSDKIdentity.Types.Tag | |
| Generic Tag Source # | |
| Show Tag Source # | |
| NFData Tag Source # | |
Defined in Amazonka.ChimeSDKIdentity.Types.Tag | |
| Eq Tag Source # | |
| Hashable Tag Source # | |
Defined in Amazonka.ChimeSDKIdentity.Types.Tag | |
| type Rep Tag Source # | |
Defined in Amazonka.ChimeSDKIdentity.Types.Tag type Rep Tag = D1 ('MetaData "Tag" "Amazonka.ChimeSDKIdentity.Types.Tag" "amazonka-chime-sdk-identity-2.0-4Oyp0DV6v8255OObqkKpjC" 'False) (C1 ('MetaCons "Tag'" 'PrefixI 'True) (S1 ('MetaSel ('Just "key") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 (Sensitive Text)) :*: S1 ('MetaSel ('Just "value") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 (Sensitive Text)))) | |
Create a value of Tag with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:key:Tag', tag_key - The key in a tag.
$sel:value:Tag', tag_value - The value in a tag.